<?php

    require("php/basicteamstatslayout.php");
    
    
    Class Font {
	var $font;
	var $charwidth;
	var $charheight;
	
	function Font($file) {
	    $this->font = ImageCreateFromPng($file);
	    $this->charwidth = ImageSX($this->font) / 15;
	    $this->charheight = ImageSY($this->font);
	}
	
	function getFontHeight() {
	    return $this->charheight;
	}
	
	function getFontWidth() {
	    return $this->charwidth;
	}
	
	function getTextImage($str) {
	    $len = strlen($str);
	    $width = $len * $this->getFontWidth();
	    $im = ImageCreate($width, $this->getFontHeight());
	    for($n=0; $n < $len; $n++) {
		imagecopy($im, 
		          $this->font, 
			  ($n * $this->getFontWidth()), 
			  0, 
			  ($this->getCharIndex($str[$n])*$this->getFontWidth()), 
			  0, 
			  $this->getFontWidth(), 
			  $this->getFontHeight());
	    }
	    
	    return $im;
	}
	
	function getCharIndex($chr) {
	    if(strlen($chr) == 1) {
		if(($chr >= "0") && ($chr <= "9")) {
		    return $chr;
		} else if($chr == "+") {
		    return 10;
		} else if($chr == "-") {
		    return 11;
		} else if($chr == ".") {
		    return 12;
		} else if($chr == " ") {
		    return 13;
		}
	    }
	    return 14;       ## This should be a "E" in the font
	}
	
	function getCharImage($chr) {
	    $im = ImageCreate($this->getFontWidth(), $this->getFontHeight());
    	    imagecopy($im, 
	              $this->font, 
		      0, 
	    	      0, 
		      ($this->getCharIndex($str)*$this->getFontWidth()), 
		      0, 
		      $this->getFontWidth(), 
		      $this->getFontHeight());
	    return $im;
	}
	
	function ColorSet($index, $red, $green, $blue) {
	    ImageColorSet($this->font, $index, $red, $green, $blue);
	}
    }
    

    Class TeamstatsLayout extends BasicTeamstatsLayout {
    
	# Dimensions of the counter
	var $width  = 241;
	var $height =  43;
	var $tx     =   4;
	var $ty     =   1;
	
	
	var $im, $white, $red, $gray, $lightgray, $lightblue, $text_color, $border_color, $background_color, $tcol, $bcol;
	

	function printBox()
        {
	    imagerectangle($this->im, 0, 0, $this->width -15, $this->height -1, $this->border_color);
	    imagerectangle($this->im, $this->width-1, 0, $this->width -15 , $this->height-1, $this->border_color);
	    imagestringup($this->im, 1,$this->width -12, $this->height -3, "Userstats",$this->text_color);
	}
			    
			    
	function initColors() {
	    global $tcolor, $tc, $bgcolor, $bg, $bcolor, $bc;
	    
	    if(isset($tcolor)) {
		$tc = $tcolor;
	    }
	    
	    if(isset($bgcolor)) {
		$bg = $bgcolor;
	    }
	    
	    if(isset($bc)) {
		$bcolor = $bc;
	    }
	    
	    $xml = $this->getProperties();
	    
	    if(!is_array($this->tcol)) {
		if (!isset($tc)) {
		    $found = $xml->search_attributes("properties:property","1:?","name","textcolor");
		    $tc = $xml->get_attribute("properties:property:defaultvalue", "1:" . $found[0] . ":1", "value");
		}
		$this->tcol = explode(",",$tc);
	    }
	    
	    if(!is_array($this->bgcol)) {
		if (!$bg) {
		    $found = $xml->search_attributes("properties:property","1:?","name","bgcolor");
		    $bg = $xml->get_attribute("properties:property:defaultvalue", "1:" . $found[0] . ":1", "value");
		}
		$this->bgcol = explode(",",$bg);
	    }
	    
	    if(!is_array($this->bcol)) {
		if (!$bcolor) {
		    $bcolor = "64,64,64";
		}
		$this->bcol = explode(",",$bcolor);
	    }
	}
	
	
	function init() {
	    
	    
	    # initialize image pointer
	    $this->im = @imagecreate($this->width, $this->height);

	    # Farben definieren
	    $this->white = ImageColorAllocate($this->im, 255,255,255);
#	    ImageColorTransparent($this->im, $this->white); # wei = transparent
	    
	    $this->red = ImageColorAllocate($this->im, 255,0,0);
	    $this->gray = ImageColorAllocate($this->im, 128,128,128);
	    $this->lightgray = ImageColorAllocate($this->im, 224,224,224);
	    $this->lightblue = ImageColorAllocate($this->im, 128,128,255);
	    
	    
	    $this->initColors();
	    $this->text_color = ImageColorAllocate($this->im, $this->tcol[0], $this->tcol[1], $this->tcol[2]);
	    $this->border_color = ImageColorAllocate($this->im, $this->bcol[0], $this->bcol[1], $this->bcol[2]);
	    $this->background_color = ImageColorAllocate($this->im, $this->bgcol[0], $this->bgcol[1], $this->bgcol[2]);
	}
	
	
	    
	/**
	 * returns the properties of this layout as a xml object
	 *
	 */
	function getProperties()
	{
	  if(!isset($this->xml)) {
	    $myXML = BasicTeamstatsLayout::getProperties();
	    
	    $i = 0;
	    
	    # Text color
	    $i++;
	    $myXML->create_tag("properties","1","property");
	    $myXML->set_attribute("properties:property", "1:$i", "name", "textcolor");
	    $myXML->set_attribute("properties:property", "1:$i", "alias", "tc");
	    $myXML->create_tag("properties:property","1:$i","type");
	    $myXML->set_attribute("properties:property:type","1:$i:1", "value", "rgb") ;
	    $myXML->create_tag("properties:property","1:$i","defaultvalue");
	    $myXML->set_attribute("properties:property:defaultvalue", "1:$i:1", "value", "0,255,0") ; // Standardwert
	    
	    # Background color
	    $i++;
	    $myXML->create_tag("properties","1","property");
	    $myXML->set_attribute("properties:property", "1:$i", "name", "bgcolor");
	    $myXML->set_attribute("properties:property", "1:$i", "alias", "bg");
	    $myXML->create_tag("properties:property","1:$i","type");
	    $myXML->set_attribute("properties:property:type","1:$i:1", "value", "rgb") ;
	    $myXML->create_tag("properties:property","1:$i","defaultvalue");
	    $myXML->set_attribute("properties:property:defaultvalue", "1:$i:1", "value", "0,0,0") ; // Standardwert
	    
	    # Size of caption
	    $i++;
	    $myXML->create_tag("properties","1","property");
	    $myXML->set_attribute("properties:property", "1:$i", "name", "captionsize");
	    $myXML->set_attribute("properties:property", "1:$i", "alias", "cs");
	    $myXML->create_tag("properties:property","1:$i","defaultvalue");
	    $myXML->set_attribute("properties:property:defaultvalue", "1:$i:1", "value", "3") ; // Standardwert
	    $myXML->create_tag("properties:property","1:$i","type");
	    $myXML->set_attribute("properties:property:type", "1:$i:1", "value", "list");
	    $myXML->create_tag("properties:property","1:$i","values");
	    $myXML->set_tag_text("properties:property:values","1:$i:1","1;2;3;4;5");
	    
	    # Image format
	    $i++;
	    $myXML->create_tag("properties","1","property");
	    $myXML->set_attribute("properties:property", "1:$i", "name", "graficsformat");
	    $myXML->set_attribute("properties:property", "1:$i", "alias", "gf");
	    $myXML->create_tag("properties:property","1:$i","type");
	    $myXML->set_attribute("properties:property:type","1:$i:1", "value", "key_value") ;
	    $myXML->create_tag("properties:property","1:$i","defaultvalue");
	    $myXML->set_attribute("properties:property:defaultvalue", "1:$i:1", "value", "png") ; // Standardwert

	    $knowntypes = imagetypes();
	    
	    if($knowntypes & IMG_PNG)
	    {
		    $values .= ";png";
		    $keys   .= ";Portable Network Grafics Format (PNG)";
		    if(strlen($default) == 0)
		    {
			$default = "png";
		    }
	    }
	    
	    if($knowntypes & IMG_JPG)
	    {
		    $values .= ";jpg;jpg75;jpg50;jpg25";
		    $keys   .= ";Jpeg Format (Quality: 100%);Jpeg Format (Quality: 75%);Jpeg Format (Quality: 50%);Jpeg Format (Quality: 25%)";
		    if(strlen($default) == 0)
		    {
			$default = "jpg";
		    }
	    }
	    
	    if($knowntypes & IMG_GIF)
	    {
		    $values .= ";gif";
		    $keys   .= ";Grafics Interchange Format (GIF)";
		    if(strlen($default) == 0)
		    {
			$default = "gif";
		    }
	    }
	    
	    if($knowntypes & IMG_WBMP)
	    {
		    $values .= ";wbmp";
		    $keys   .= ";WAP Bitmap Format (WBMP)";
		    if(strlen($default) == 0)
		    {
			$default = "wbmp";
		    }
	    }
		    
	    $myXML->create_tag("properties:property","1:$i","defaultvalue");
	    $myXML->set_attribute("properties:property:defaultvalue", "1:$i:1", "value", $default) ; // Standardwert
	    
	    $myXML->create_tag("properties:property","1:$i","keys");
	    $myXML->create_tag("properties:property","1:$i","values");
	    $myXML->set_attribute("properties:property:keys", "1:$i:1", "value", substr($keys, 1)) ; // Werte
	    $myXML->set_attribute("properties:property:values", "1:$i:1", "value", substr($values, 1)) ; // Schluessel
	    
	    
	    
	    
	    $this->xml = $myXML;
	  } else {
	    $myXML = $this->xml;
	  }
	  return $myXML;
	}
	
	
	
        function showError($headline, $msg, $status="")
	{
	
	    $this->width  = 241;
	    $this->height =  58;
	    $this->tx     =   4;
	    $this->ty     =   1;
	    $this->init();
	    $this->printBox();
	
	    $charsPerLine = ($this->width -17)/imagefontwidth(2);
	
    	    # headline
	    imagestring($this->im, 3, $this->tx +1, 1, $headline, $this->gray );
	    imagestring($this->im, 3, $this->tx ,   0, $headline, $this->red );
	
	    #message
	    $msgwords = strtok($msg, " ");
	    $line = 1;
	    $text = "";
	    while($msgwords) {
		if((strlen($text) + strlen($msgwords)) > $charsPerLine) {
		    imagestring($this->im, 2, $this->tx , ($line * 12), $text, $this->text_color );
		    $line++;
		    $text = "";
		}
		$text .= $msgwords . " ";
		$msgwords = strtok(" ");
	    }
	    if(strlen(text) > 0) {
		imagestring($this->im, 2, $this->tx , ($line * 12), $text, $this->text_color );
	    }
	    imagestring($this->im, 2, $this->tx ,  48, $status, $this->text_color );
	
	    $this->error  = true;
	
	    $this->sendGrafic();
	}
	
	
	function sendGrafic()
	{
	    global $gf;
	    
	    $xml = $this->getProperties();
	    
	    if (!isset($gf)) {
		$found = $xml->search_attributes("properties:property","1:?","name","graficsformat");
		$gf = $xml->get_attribute("properties:property:defaultvalue", "1:" . $found[0] . ":1", "value");
	    }
	    
	    # Grafik ausgeben
	    if(substr($gf, 0, 3) == "jpg") {
		header('Content-type: image/jpeg');
		if($gf == "jpg")
		    imagejpeg($this->im);
		else if($gf == "jpg75")
		    imagejpeg($this->im, '', 75);
		else if($gf == "jpg50")
		    imagejpeg($this->im, '', 50);
		else if($gf == "jpg25")
		    imagejpeg($this->im, '', 25);
	    } else if($gf == "gif") {
		header('Content-type: image/gif');
		imagegif($this->im);
	    } else if($gf == "wbmp") {
		header('Content-type: image/vnd.wap.wbmp');
		imagewbmp($this->im);
	    } else {
		header('Content-type: image/png');
		imagepng($this->im);
	    }
	    
	}
	
	function showStats() {
	    
	
	    global $captionsize, $cs;
	
	    $this->initColors();
	    $stats = $this->stats;
	    $team  = $stats->getTeam();
	    
	
	    $bigfont = new Font("./layout/user/bitmapfonts/sbg.png");
	    $smallfont = new Font("./layout/user/bitmapfonts/sbgs.png");
	    
	    
	    $wus = $stats->getWUCount();
	    $newwus = $stats->getDiffWUCount();
	    
	    $bigfont->ColorSet(0, $this->bgcol[0], $this->bgcol[1], $this->bgcol[2]);
	    $bigfont->ColorSet(1, $this->tcol[0]/3, $this->tcol[1]/3, $this->tcol[2]/3);
	    $bigfont->ColorSet(2, $this->tcol[0], $this->tcol[1], $this->tcol[2]);
	    
	    $wu_img = $bigfont->getTextImage(number_format($wus, 0, ",", "."));

	    $smallfont->ColorSet(0, $this->bgcol[0], $this->bgcol[1], $this->bgcol[2]);
	    $smallfont->ColorSet(1, $this->tcol[0]/3, $this->tcol[1]/3, $this->tcol[2]/3);
	    $smallfont->ColorSet(2, $this->tcol[0], $this->tcol[1], $this->tcol[2]);
	    
	    if($newwus>=0) {
		$newwu_f = "+";
	    }
	    
	    $newwu_img = $smallfont->getTextImage(" " . $newwu_f . number_format($newwus, 0, ",", "."));
	
	    if(isset($captionsize)) {
		$cs = $captionsize;
	    }
	    
	    if(!isset($cs)) {
		$xml   = $this->getProperties();
		$found = $xml->search_attributes("properties:property","1:?","name","captionsize");
		$font1 = $xml->get_attribute("properties:property:defaultvalue", "1:" . $found[0] . ":1", "value");
	    } else {
		$font1 = $cs;
	    }
	    
	    $font2        =   1;
	    $this->tx     =   4;
	    $this->ty     =   2;
	    $name = strtr($team->getName(), "", "23");
	    $this->width  = max(ImageSX($wu_img) + ImageSX($newwu_img), (imagefontwidth($font2) * strlen($GLOBALS["sponsored_by"])), (imagefontwidth($font1) * strlen($name))) + 2* $this->tx;
	    $this->height =  $bigfont->getFontHeight() + imagefontheight($font1) + imagefontheight($font2) + 3*$this->ty;
	    
	    
	    $this->init();
	    $im = $this->im;
	    
	    imagefilledrectangle($im, 0, 0, $this->width, $this->height, $this->background_color);
	    imagestring($this->im, $font1, $this->tx ,  $this->ty - 1, $name, $this->text_color );
	    imagecopy($im, $wu_img, $this->tx, 2*$this->ty - 1 + imagefontheight($font1), 0, 0, ImageSX($wu_img), ImageSY($wu_img));
	    imagecopy($im, $newwu_img, $this->tx + ImageSX($wu_img), 2*$this->ty - 1 + imagefontheight($font1), 0, 0, ImageSX($newwu_img), ImageSY($newwu_img));
	    imagestring($this->im, $font2, $this->tx ,  $this->height-$this->ty-imagefontheight($font2), $GLOBALS["sponsored_by"], $this->text_color );
	    
	    
	    imagestring($this->im, $font, $this->tx ,  $this->height-$this->ty-imagefontheight($font), $GLOBALS["sponsored_by"], $this->text_color );
	    
	    $this->sendGrafic();
	}
	
	
	
    }

?>